from setuptools import setup

setup(name='stat_gaussian_binomial_distributions',
      version='0.2',
      description="Gaussian distributions and binomial distributions. This is a assignment package. If you are looking for  anything similar to this, then I don't recommend using this as this may contain bugs.",
      packages=['stat_gaussian_binomial_distributions'],
      author="gns",
      zip_safe=False)
